OpenAI Gym Envs
===============

`OpenAI Gym's documentation <https://github.com/openai/gym/blob/master/docs/creating-environments.md>_`

Installation
------------

First install OpenAI Gym :

.. code-block:: console

    $ pip3 install --no-cache-dir --upgrade gym

Then install the AmLE :

.. code-block:: console

    $ pip3 install --no-cache-dir --upgrade amle-py

Finally instal the amle environment for OpenAi Gym :

.. code-block:: console

    $ pip3 install --no-cache-dir --upgrade gym-cap32

Examples
--------

You can run two different examples with the two given games. To run them make sure to have installed everything required above. Then in Examples/ :

.. code-block:: console

    $ python3 <example-file>
